@@ -15,9 +15,10 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-#
+from __future__ import annotations
+
 import subprocess
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union
+from typing import TYPE_CHECKING, Any
 
 from airflow.exceptions import AirflowException, AirflowNotFoundException
 from airflow.hooks.base import BaseHook
@@ -49,30 +50,30 @@ class SparkSqlHook(BaseHook):
         (Default: The ``queue`` value set in the Connection, or ``"default"``)
     """
 
-    conn_name_attr = 'conn_id'
-    default_conn_name = 'spark_sql_default'
-    conn_type = 'spark_sql'
-    hook_name = 'Spark SQL'
+    conn_name_attr = "conn_id"
+    default_conn_name = "spark_sql_default"
+    conn_type = "spark_sql"
+    hook_name = "Spark SQL"
 
     def __init__(
         self,
         sql: str,
-        conf: Optional[str] = None,
+        conf: str | None = None,
         conn_id: str = default_conn_name,
-        total_executor_cores: Optional[int] = None,
-        executor_cores: Optional[int] = None,
-        executor_memory: Optional[str] = None,
-        keytab: Optional[str] = None,
-        principal: Optional[str] = None,
-        master: Optional[str] = None,
-        name: str = 'default-name',
-        num_executors: Optional[int] = None,
+        total_executor_cores: int | None = None,
+        executor_cores: int | None = None,
+        executor_memory: str | None = None,
+        keytab: str | None = None,
+        principal: str | None = None,
+        master: str | None = None,
+        name: str = "default-name",
+        num_executors: int | None = None,
         verbose: bool = True,
-        yarn_queue: Optional[str] = None,
+        yarn_queue: str | None = None,
     ) -> None:
         super().__init__()
-        options: Dict = {}
-        conn: Optional[Connection] = None
+        options: dict = {}
+        conn: Connection | None = None
 
         try:
             conn = self.get_connection(conn_id)
@@ -109,7 +110,7 @@ class SparkSqlHook(BaseHook):
     def get_conn(self) -> Any:
         pass
 
-    def _prepare_command(self, cmd: Union[str, List[str]]) -> List[str]:
+    def _prepare_command(self, cmd: str | list[str]) -> list[str]:
         """
         Construct the spark-sql command to execute. Verbose output is enabled
         as default.
@@ -161,7 +162,7 @@ class SparkSqlHook(BaseHook):
 
     def run_query(self, cmd: str = "", **kwargs: Any) -> None:
         """
-        Remote Popen (actually execute the Spark-sql query)
+        Remote Popen (actually execute the Spark-sql query).
 
         :param cmd: command to append to the spark-sql command
         :param kwargs: extra arguments to Popen (see subprocess.Popen)
@@ -184,7 +185,7 @@ class SparkSqlHook(BaseHook):
             )
 
     def kill(self) -> None:
-        """Kill Spark job"""
+        """Kill Spark job."""
         if self._sp and self._sp.poll() is None:
             self.log.info("Killing the Spark-Sql job")
             self._sp.kill()
